@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
+import json
 
-from typing import Literal, Union, Type, Any, TypeVar
+from typing import Literal, Union, Type, Any, TypeVar, List, get_args, get_origin
 
 import aiohttp
 from patchwork.core import Component
@@ -129,8 +130,8 @@ class HTTPConnector(Component):
     async def _handle_response(
             self,
             response: aiohttp.ClientResponse,
-            response_model: Union[Type[BaseModel], Any, None]
-    ) -> Union[BaseModel, None]:
+            response_model: Union[Type[BaseModel], Any, None, List[BaseModel]]
+    ) -> Union[BaseModel, List[BaseModel], None]:
 
         if response.status in {200, 201, 202}:
             if response_model is Any:
@@ -144,7 +145,18 @@ class HTTPConnector(Component):
                 raise ValueError('missing data')
 
             data = await response.read()
-            return response_model.parse_raw(data, proto=Protocol.json)
+            if response.content_type == 'application/json':
+                data = json.loads(data)
+
+            orig = get_origin(response_model)
+            if orig is list:
+                if not isinstance(data, list):
+                    raise ValueError("list is expected, but endpoint returned not a list")
+
+                model = get_args(response_model)[0]
+                return [model(**d) for d in data]
+
+            return response_model(**data)
         elif response.status == 204:
             if response_model is not Any and response_model is not None:
                 raise ValueError('response data expected, but 204 No Content response received')
