@@ -6,6 +6,7 @@ from jose import JWTError
 from pydantic import BaseModel
 from starlette import status
 from starlette.requests import Request
+from starlette.websockets import WebSocket
 
 from patchwork.core import AsyncPublisher
 from .settings import is_tortoise_installed
@@ -41,7 +42,8 @@ credentials_exception = HTTPException(
 
 
 def get_token(name: str, optional: bool = False):
-    def _get(request: Request):
+    def _get(request: Request = None, websocket: WebSocket = None):
+        request = request or websocket
         try:
             token = request['token'][name]
         except KeyError:
